@@ -28,8 +28,7 @@ class GitIssuePublisher(Publisher):
             self.sha = sha
             self.user = self.__github.get_user().login
         except GithubException as e:
-            print(f"Error initializing GitHub client: {e}")
-            raise
+            raise Exception(f"Error initializing GitHub client: {e}")
 
     def __get_repo(self):
         """
@@ -40,8 +39,7 @@ class GitIssuePublisher(Publisher):
         try:
             return self.__github.get_repo(self.repo)
         except GithubException as e:
-            print(f"Error retrieving repository {self.repo}: {e}")
-            raise
+            raise Exception(f"Error retrieving repository {self.repo}: {e}")
 
 
     def publish(self, data):
@@ -56,16 +54,15 @@ class GitIssuePublisher(Publisher):
 
             existing_issue = self.get_thread(title)
 
-            main_comment = existing_issue.get_comments()[0]
-            updated_body = self.append_data_to_comment(main_comment.body, data['message']['adherence'])
-            main_comment.edit(updated_body)
+            # main_comment = existing_issue.get_comments()[0]
+            updated_body = self.append_data_to_comment(existing_issue.body, data['message']['adherence'])
+            existing_issue.edit(body=updated_body)
 
             existing_issue.create_comment(self.generate_report(data))
 
             return 
         except GithubException as e:
-            print(f"Error publishing issue: {e}")
-            raise
+            raise Exception(f"Error publishing issue: {e}")
  
     def get_thread(self, title: str, body: Optional[str] = ''):
         """
@@ -98,8 +95,7 @@ class GitIssuePublisher(Publisher):
             return new_issue
 
         except GithubException as e:
-            print(f"Error threading issue: {e}")
-            raise
+            raise Exception(f"Error threading issue: {e}")
 
     def generate_report(self, data):
         report = [
